FileWriter

Struct FileWriter 

pub struct FileWriter { /* private fields */ }
File-backed writer that writes bytes to a file on disk.

Implementations

Source

impl FileWriter

pub fn create<P: AsRef<Path>>(path: P) -> Result<Self>

Create a new writer that will write to the given path.

pub fn flush_to_disk(&self) -> Result<()>

Flush the current data to disk.

pub fn path(&self) -> &Path

Returns the target path.